Module: Jekyll

Defined in:
lib/jekyll/line_awesome.rb,
lib/jekyll/date_de.rb,
lib/octopod/version.rb,
lib/jekyll/static_file.rb,
lib/jekyll/update_config.rb,
lib/jekyll/flattr_filters.rb,
lib/jekyll/octopod_filters.rb,
lib/jekyll/paged_feed_page.rb,
lib/jekyll/podigee_player_tag.rb,
lib/jekyll/podcast_player_page.rb,
lib/jekyll/paged_feed_page_generator.rb,
lib/jekyll/podcast_player_page_generator.rb

Overview

The MIT License (MIT)

Copyright (c) 2014 Ryan Morrissey

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Line Awesome Icons Liquid Tag Documentation can be found at https://icons8.com/line-awesome

Example:

{% icon la-camera-retro %}
{% icon la-camera-retro la-lg %}
{% icon la-spinner la-spin %}
{% icon la-shield la-rotate-90 %}

Defined Under Namespace

Modules: DateDe, FlattrFilters, OctopodFilters, UpdateConfig Classes: LineAwesomeTag, Octopod, PagedFeedPage, PagedFeedPageGenerator, PodcastPlayerPage, PodcastPlayerPageGenerator, PodigeePlayerTag, StaticFile